==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/GXModules/Gambio/Widgets/ProductList/TextPhrases/german/productListWidget.lang.inc.php <==
<?php
/*--------------------------------------------------------------------------------------------------
    productWidget.lang.inc.php 2019-08-29
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

$t_language_text_section_content_array = [
    'title'                 => 'Produktliste',
    'description'           => 'Mit diesem Widget kannst du ganz einfach Produkt-Slider zu deinem Shop hinzufügen',
    'options.general.title' => 'Allgemein',
    
    'options.id.label'       => 'ID',
    'options.id.placeholder' => 'HTML Element ID',
    
    'options.class.label'       => 'Klasse',
    'options.class.placeholder' => 'HTML Element Klasse',
    
    'options.product.title' => 'Produkt',
    
    'options.product.label'       => 'Produkt wählen',
    'options.product.placeholder' => 'Produkt-ID oder -namen suchen...',
    
    'options.category.title' => 'Kategorie',
    
    'options.category.label'       => 'Kategorie auswählen',
    'options.category.placeholder' => 'Kategorie-ID oder -namen suchen',
    
    'preview.placeholder' => 'Klicken Sie auf den Bleistift, um Produkte hinzuzufügen oder eine Kategorie auszuwählen',
    
    'options.presentation.title'          => 'Darstellung',
    'options.presentation.label'          => 'Darstellung',
    'options.presentation.options.slider' => 'Slider',
    'options.presentation.options.list'   => 'Liste',
    
    'options.maxProducts.label'       => 'Max. angezeigte Artikel',
    'options.maxProducts.placeholder' => 'placeholder',
    
    'options.random.label' => 'Artikel zufällig anzeigen',

    'options.itemPerRowXs.label' => 'Artikel pro Zeile Mobil',
    'options.itemPerRowSm.label' => 'Artikel pro Zeile Klein',
    'options.itemPerRowMd.label' => 'Artikel pro Zeile Medium',
    'options.itemPerRowLg.label' => 'Artikel pro Zeile Groß',
    
    'options.listType.label'               => 'Artikelauswahl',
    'options.listType.placeholder'         => 'Artikelauswahl',
    'options.listType.options.own.list'    => 'Eigene Liste',
    'options.listType.options.category'    => 'Kategorien',
    'options.listType.options.deals'       => 'Angebote',
    'options.listType.options.recommended' => 'Empfohlene Artikel',
    'options.listType.options.comingSoon'  => 'Erscheint bald',
    'options.listType.options.new'         => 'Neu',
    
    'options.productList.label' => 'Product'
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GXModules/Gambio/Widgets/ProductList/TextPhrases/german/productListWidget.lang.inc.php <==
<?php
/*--------------------------------------------------------------------------------------------------
    productWidget.lang.inc.php 2019-08-29
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

$t_language_text_section_content_array = [
    'title'                 => 'Produktliste',
    'description'           => 'Mit diesem Widget kannst du ganz einfach Produkt-Slider zu deinem Shop hinzufügen',
    'options.general.title' => 'Allgemein',
    
    'options.id.label'       => 'ID',
    'options.id.placeholder' => 'HTML Element ID',
    
    'options.class.label'       => 'Klasse',
    'options.class.placeholder' => 'HTML Element Klasse',
    
    'options.product.title' => 'Produkt',
    
    'options.product.label'       => 'Produkt wählen',
    'options.product.placeholder' => 'Produkt-ID oder -namen suchen...',
    
    'options.category.title' => 'Kategorie',
    
    'options.category.label'       => 'Kategorie auswählen',
    'options.category.placeholder' => 'Kategorie-ID oder -namen suchen',
    
    'preview.placeholder' => 'Klicken Sie auf den Bleistift, um Produkte hinzuzufügen oder eine Kategorie auszuwählen',
    
    'options.presentation.title'          => 'Darstellung',
    'options.presentation.label'          => 'Darstellung',
    'options.presentation.options.slider' => 'Slider',
    'options.presentation.options.list'   => 'Liste',
    
    'options.maxProducts.label'       => 'Max. angezeigte Produkte',
    'options.maxProducts.placeholder' => 'placeholder',
    
    'options.random.label' => 'Produkte zufällig anzeigen',

    'options.itemPerRowXs.label' => 'Produkte pro Zeile Mobil',
    'options.itemPerRowSm.label' => 'Produkte pro Zeile Klein',
    'options.itemPerRowMd.label' => 'Produkte pro Zeile Medium',
    'options.itemPerRowLg.label' => 'Produkte pro Zeile Groß',
    
    'options.listType.label'               => 'Produktauswahl',
    'options.listType.placeholder'         => 'Produktauswahl',
    'options.listType.options.own.list'    => 'Eigene Liste',
    'options.listType.options.category'    => 'Kategorien',
    'options.listType.options.deals'       => 'Angebote',
    'options.listType.options.recommended' => 'Empfohlene Produkte',
    'options.listType.options.comingSoon'  => 'Erscheint bald',
    'options.listType.options.new'         => 'Neu',
    
    'options.productList.label' => 'Produkt'
];
